
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef __IDE_ENUMS_H__
#define __IDE_ENUMS_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "tmpl-error.h" */
GType tmpl_error_get_type (void);
#define TMPL_TYPE_ERROR (tmpl_error_get_type ())

/* enumerations from "tmpl-expr-types.h" */
GType tmpl_symbol_type_get_type (void);
#define TMPL_TYPE_SYMBOL_TYPE (tmpl_symbol_type_get_type ())
GType tmpl_expr_type_get_type (void);
#define TMPL_TYPE_EXPR_TYPE (tmpl_expr_type_get_type ())
GType tmpl_expr_builtin_get_type (void);
#define TMPL_TYPE_EXPR_BUILTIN (tmpl_expr_builtin_get_type ())
G_END_DECLS

#endif /* __IDE_ENUMS_H__ */

/* Generated data ends here */

